==> v8.3.zip: ru_twords_ru_tw/bible/kt/boast.md <==
# хвалиться, хвастаться, хвастливый

## Определение:

Термин “хвалиться” означает гордо говорить о ком-либо или о чём-либо, часто о самом себе.

* Хвастливый человек говорит о себе гордо.
* Бог упрекал израильтян в том, что они хвалились своими идолами, упрямо поклонялись ложным богам вместо истинного Бога.
* В Библии также говорится о людях, хвалящихся такими вещами, как богатство, сила, плодородные поля, законы и прочее. Это значит, что они гордились этим и не признавали, что всё это дал им Бог.
* Бог призывал израильтян хвалиться или гордиться тем, что они знают Его.
* Апостол Павел говорил, что хвалится Господом, то есть радуется о Боге и благодарит Его за всё, что Он сделал.

## Варианты перевода:

* Слово “хвалиться” можно также перевести как “хвастаться”, “гордо говорить” или “быть гордым”.
* Слово “хвастливый” можно перевести как: “наполненный гордыми высказываниями”, “гордый”, “надменный” или “говорящий о себе слишком возвышенно”.
* В контексте “хвалиться Богом и Его познанием” это слово можно перевести как “гордиться Богом”, “прославлять Бога”, “радоваться Богу” или “благодарить Бога за ...”
* В некоторых языках есть два слова, обозначающие понятие “гордость”: одно с отрицательным значением (быть гордым или надменным), а другое с положительным (гордиться своим делом, семьёй или страной).

## Варианты перевода:

(См. также: [гордый](../other/proud.md))

## Ссылки на библейский текст:

* [3 Цар. 20:11-12](rc://*/tn/help/1ki/20/11)
* [2 Тим. 3:1-4](rc://*/tn/help/2ti/03/01)
* [Иак. 3:13-14](rc://*/tn/help/jas/03/13)
* [Иак. 4:15-17](rc://*/tn/help/jas/04/15)
* [Пс. 44:7-8](rc://*/tn/help/psa/044/007)

## Данные о слове:

* Номера Стронга: H1984, H3235, H6286, G212, G213, G2620, G2744, G2745, G2746, G3166

==> v9.2.zip: ru_twords_ru_tw/bible/kt/boast.md <==
# хвалиться, хвастаться, хвастливый

## Определение:

Термин “хвалиться” означает гордо говорить о ком-либо или о чём-либо, часто о самом себе.
* Хвастливый человек говорит о себе гордо.
* Бог упрекал израильтян в том, что они хвалились своими идолами, упрямо поклонялись ложным богам вместо истинного Бога.
* В Библии также говорится о людях, хвалящихся такими вещами, как богатство, сила, плодородные поля, законы и прочее. Это значит, что они гордились этим и не признавали, что всё это дал им Бог.
* Бог призывал израильтян хвалиться или гордиться тем, что они знают Его.
* Апостол Павел говорил, что хвалится Господом, то есть радуется о Боге и благодарит Его за всё, что Он сделал.

## Варианты перевода:

* Слово “хвалиться” можно также перевести как “хвастаться”, “гордо говорить” или “быть гордым”.
* Слово “хвастливый” можно перевести как: “наполненный гордыми высказываниями”, “гордый”, “надменный” или “говорящий о себе слишком возвышенно”.
* В контексте “хвалиться Богом и Его познанием” это слово можно перевести как “гордиться Богом”, “прославлять Бога”, “радоваться Богу” или “благодарить Бога за ...”
* В некоторых языках есть два слова, обозначающие понятие “гордость”: одно с отрицательным значением (быть гордым или надменным), а другое с положительным (гордиться своим делом, семьёй или страной).

## Варианты перевода:

(См. также: [гордый](../other/proud.md))

## Ссылки на библейский текст:

* [3 Цар. 20:11-12](rc://ru/tn/help/1ki/20/11)
* [2 Тим. 3:1-4](rc://ru/tn/help/2ti/03/01)
* [Иак. 3:13-14](rc://ru/tn/help/jas/03/13)
* [Иак. 4:15-17](rc://ru/tn/help/jas/04/15)
* [Пс. 44:7-8](rc://ru/tn/help/psa/044/007)


## Данные о слове:

* Номера Стронга: H1984, H3235, H6286, G212, G213, G2620, G2744, G2745, G2746, G3166
